summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmrotateedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmrotateedit.h')
-rw-r--r--kpovmodeler/pmrotateedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmrotateedit.h b/kpovmodeler/pmrotateedit.h
index 147c4b1c..202af2b3 100644
--- a/kpovmodeler/pmrotateedit.h
+++ b/kpovmodeler/pmrotateedit.h
@@ -39,9 +39,9 @@ class PMRotateEdit : public PMDialogEditBase
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMRotateEdit with tqparent and name
*/
- PMRotateEdit( TQWidget* tqparent, const char* name = 0 );
+ PMRotateEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMRotateEdit : public PMDialogEditBase
public:
/**
- * Creates a PMRotateEdit with tqparent and name
+ * Creates a PMRotateEdit with parent and name
*/